.. _autodoc:

**************
Documentation
**************

sigc
=============
#-------------

# .. automodule:: sigc.sigc
#  :members:


# genesets2GeneSig
# **************

#.. automodule:: sigc.genesets2GeneSig
#  :members:

